@@ -20,7 +20,7 @@
    */
   function createHttpClient(options) {
     options.caCerts ??= [];
-    return new HttpClient(core.opSync("op_create_http_client", options));
+    return new HttpClient(core.opSync("op_fetch_custom_client", options));
   }
 
   class HttpClient {
