@@ -27,7 +27,6 @@
     abortedNetworkError,
   } = window.__bootstrap.fetch;
   const abortSignal = window.__bootstrap.abortSignal;
-  const { DOMException } = window.__bootstrap.domException;
   const {
     ArrayPrototypePush,
     ArrayPrototypeSplice,
@@ -37,6 +36,7 @@
     PromisePrototypeThen,
     PromisePrototypeCatch,
     String,
+    StringPrototypeStartsWith,
     StringPrototypeToLowerCase,
     TypedArrayPrototypeSubarray,
     TypeError,
@@ -87,10 +87,7 @@
   function createResponseBodyStream(responseBodyRid, terminator) {
     function onAbort() {
       if (readable) {
-        errorReadableStream(
-          readable,
-          new DOMException("Ongoing fetch was aborted.", "AbortError"),
-        );
+        errorReadableStream(readable, terminator.reason);
       }
       core.tryClose(responseBodyRid);
     }
@@ -120,9 +117,7 @@
         } catch (err) {
           RESOURCE_REGISTRY.unregister(readable);
           if (terminator.aborted) {
-            controller.error(
-              new DOMException("Ongoing fetch was aborted.", "AbortError"),
-            );
+            controller.error(terminator.reason);
           } else {
             // There was an error while reading a chunk of the body, so we
             // error.
@@ -154,9 +149,7 @@
       }
 
       const body = new InnerBody(req.blobUrlEntry.stream());
-      terminator[abortSignal.add](() =>
-        body.error(new DOMException("Ongoing fetch was aborted.", "AbortError"))
-      );
+      terminator[abortSignal.add](() => body.error(terminator.reason));
 
       return {
         headerList: [
@@ -327,6 +320,7 @@
   /**
    * @param {InnerRequest} request
    * @param {InnerResponse} response
+   * @param {AbortSignal} terminator
    * @returns {Promise<InnerResponse>}
    */
   function httpRedirectFetch(request, response, terminator) {
@@ -404,7 +398,7 @@
       const request = toInnerRequest(requestObject);
       // 4.
       if (requestObject.signal.aborted) {
-        reject(abortFetch(request, null));
+        reject(abortFetch(request, null, requestObject.signal.reason));
         return;
       }
 
@@ -415,7 +409,9 @@
       // 10.
       function onabort() {
         locallyAborted = true;
-        reject(abortFetch(request, responseObject));
+        reject(
+          abortFetch(request, responseObject, requestObject.signal.reason),
+        );
       }
       requestObject.signal[abortSignal.add](onabort);
 
@@ -432,7 +428,13 @@
             if (locallyAborted) return;
             // 12.2.
             if (response.aborted) {
-              reject(request, responseObject);
+              reject(
+                abortFetch(
+                  request,
+                  responseObject,
+                  requestObject.signal.reason,
+                ),
+              );
               requestObject.signal[abortSignal.remove](onabort);
               return;
             }
@@ -458,8 +460,7 @@
     });
   }
 
-  function abortFetch(request, responseObject) {
-    const error = new DOMException("Ongoing fetch was aborted.", "AbortError");
+  function abortFetch(request, responseObject, error) {
     if (request.body !== null) {
       if (WeakMapPrototypeHas(requestBodyReaders, request)) {
         WeakMapPrototypeGet(requestBodyReaders, request).cancel(error);
@@ -498,12 +499,16 @@
         // The spec is ambiguous here, see
         // https://github.com/WebAssembly/spec/issues/1138. The WPT tests
         // expect the raw value of the Content-Type attribute lowercased.
-        const contentType = res.headers.get("Content-Type");
-        if (
-          typeof contentType !== "string" ||
-          StringPrototypeToLowerCase(contentType) !== "application/wasm"
-        ) {
-          throw new TypeError("Invalid WebAssembly content type.");
+        // We ignore this for file:// because file fetches don't have a
+        // Content-Type.
+        if (!StringPrototypeStartsWith(res.url, "file://")) {
+          const contentType = res.headers.get("Content-Type");
+          if (
+            typeof contentType !== "string" ||
+            StringPrototypeToLowerCase(contentType) !== "application/wasm"
+          ) {
+            throw new TypeError("Invalid WebAssembly content type.");
+          }
         }
 
         // 2.5.
